@@ -10,7 +10,7 @@ use utf8;
 use URI;
 use Params::Validate qw/validate :types/;
 
-use Moo::Lax;
+use Moo;
 extends qw/Exporter Zabbix2::API::CRUDE/;
 
 # extracted from frontends/php/include/defines.inc.php
