@@ -7,9 +7,10 @@ use Carp;
 use autodie;
 use utf8;
 
-use Moo::Lax;
+use Moo;
 extends qw/Zabbix2::API::CRUDE/;
 use Zabbix2::API::HostInterface;
+use Zabbix2::API::Template;
 
 has 'items' => (is => 'ro',
                 lazy => 1,
@@ -18,6 +19,9 @@ has 'interfaces' => (is => 'rw');
 has 'hostgroups' => (is => 'ro',
                      lazy => 1,
                      builder => '_fetch_hostgroups');
+has 'templates' => (is => 'ro',
+                    lazy => 1,
+                    builder => '_fetch_templates');
 has 'graphs' => (is => 'ro',
                  lazy => 1,
                  builder => '_fetch_graphs');
@@ -91,6 +95,12 @@ sub _fetch_hostgroups {
     return $items;
 }
 
+sub _fetch_templates {
+    my $self = shift;
+    my $items = $self->{root}->fetch('Template', params => { hostids => [ $self->data->{hostid} ] });
+    return $items;
+}
+
 sub _fetch_graphs {
     my $self = shift;
     my $graphs = $self->{root}->fetch('Graph', params => { hostids => [ $self->data->{hostid} ] });
@@ -142,6 +152,7 @@ Zabbix2::API::Host -- Zabbix host objects
   my $items = $host->items;
   my $hostgroups = $host->hostgroups;
   my $graphs = $host->graphs;
+  my $templates = $host->templates;
   
   # this one doesn't
   my $interfaces = $host->interfaces;
@@ -190,9 +201,9 @@ server.
 
 (read-write arrayref of L<Zabbix2::API::HostInterface> instances)
 
-This attribute is populated automatically when the Perl object is
-updated from the "interfaces" server property (i.e. when the C<pull>
-method is called).
+This attribute is populated automatically from the "interfaces" server
+property when the Perl object is updated (i.e. when the C<pull> method
+is called).
 
 Likewise, it is automatically used to populate the "interfaces"
 property before either C<create> or C<update> are called.
@@ -200,6 +211,11 @@ property before either C<create> or C<update> are called.
 Note that "interfaces" is a required property as far as the server is
 concerned, so you must define it one way or another.
 
+You can add interfaces by pushing new L<Zabbix2::API::HostInterface>
+objects onto this arrayref and then calling C<< $host->update >>, or
+by instantiating interface objects with the C<hostid> property set and
+calling C<< $interface->create >>.
+
 =head2 items
 
 (read-only arrayref of L<Zabbix2::API::Item> objects)
@@ -207,6 +223,13 @@ concerned, so you must define it one way or another.
 This attribute is lazily populated with the host's items from the
 server.
 
+=head2 templates
+
+(read-write arrayref of L<Zabbix2::API::Template> instances)
+
+This attribute is lazily-populated with the host's templates from the
+server.
+
 =head1 SEE ALSO
 
 L<Zabbix2::API::CRUDE>.
