@@ -7,7 +7,7 @@ use Carp;
 use autodie;
 use utf8;
 
-use Moo::Lax;
+use Moo;
 extends qw/Exporter Zabbix2::API::CRUDE/;
 
 use constant {
@@ -39,6 +39,10 @@ our %EXPORT_TAGS = (
     ],
 );
 
+has 'host' => (is => 'ro',
+               lazy => 1,
+               builder => '_fetch_host');
+
 sub _prefix {
     my (undef, $suffix) = @_;
     if ($suffix) {
@@ -51,6 +55,21 @@ sub _prefix {
     }
 }
 
+sub _extension {
+    return (output => 'extend');
+}
+
+sub name {
+    my $self = shift;
+    return $self->data->{useip} == 0 ? $self->data->{dns} : $self->data->{ip};
+}
+
+sub _fetch_host {
+    my $self = shift;
+    my $host = $self->{root}->fetch_single('Host', params => { hostids => [ $self->data->{hostid} ] });
+    return $host;
+}
+
 1;
 __END__
 =pod
@@ -80,27 +99,24 @@ Zabbix2::API::HostInterface -- Zabbix host interface objects
   
   # create it later
   my $new_interface = Zabbix2::API::HostInterface->new(
-      dns => 'some other hostname',
-      ip => '',
-      useip => 0,
-      main => 1,
-      port => 10001,
-      type => Zabbix2::API::HostInterface::INTERFACE_TYPE_AGENT,
-      hostid => $new_host->id);
+      root => $zabbix,
+      data => {
+          dns => 'some other hostname',
+          ip => '',
+          useip => 0,
+          main => 1,
+          port => 10001,
+          type => Zabbix2::API::HostInterface::INTERFACE_TYPE_AGENT,
+          hostid => $new_host->id
+      });
   $new_interface->create;
 
 =head1 DESCRIPTION
 
-While technically a subclass of L<Zabbix2::API::CRUDE>, this class
-does not actually implement all methods necessary to behave as a
-full-fledged Zabbix object.  Instead, we recommend using
-L<Zabbix2::API::HostInterface> objects via their parent
-L<Zabbix2::API::Host> object.  Calls to unimplemented methods will
-throw an exception.
+Handles CRUD for Zabbix interface objects.
 
-Unlike L<Zabbix2::API::GraphItem> objects, for which the usual API
-methods are not all implemented on the server, this is mostly a case
-of laziness of our part, so patches are welcome.
+This is a subclass of C<Zabbix2::API::CRUDE>; see there for inherited
+methods.
 
 L<Zabbix2::API::HostInterface> objects will be automatically created
 from a L<Zabbix2::API::Host> object's properties whenever it is pulled
@@ -110,6 +126,15 @@ objects will be automatically turned into properties just before a
 call to C<create> or C<update>, causing the relevant host interface
 objects to be created or updated on the server.
 
+=head1 ATTRIBUTES
+
+=head2 host
+
+(read-only L<Zabbix2::API::Host> object)
+
+This attribute is lazily populated with the interface's host from the
+server.
+
 =head1 EXPORTS
 
 Some constants:
