@@ -8,7 +8,7 @@ use Carp;
 use Params::Validate qw/validate validate_with :types/;
 use Text::ParseWords;
 
-use Moo::Lax;
+use Moo;
 extends qw/Exporter Zabbix2::API::CRUDE/;
 
 use constant {
